<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form :model="searchForm" label-width="auto">
                <el-row :gutter="20">
                    <el-col :span="10">
                        <el-form-item label="文件名称">
                            <el-input v-model="searchForm.profileName" clearable placeholder="请输入文件名称"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="10">
                        <el-form-item label="文件类型">
                            <el-select clearable v-model="searchForm.profileType" placeholder="请选择文件类型"
                                style="width: 100%">
                                <el-option v-for="item in fileTypeOptions" :key="item.id" :label="item.name"
                                    :value="item.value">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch()">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="handleAdd">
                        {{ this.$t('common.add') }}
                    </el-button>
                    <el-button slot="reference" icon="el-icon-delete" type="danger" class="btn btn-delete"
                        :disabled="!deleteIds" @click="handleDelete">
                        {{ this.$t('common.delete') }}
                    </el-button>
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table v-loading="loading" stripe size="mini" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }"
                        @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55" align="center"></el-table-column>
                        <el-table-column type="index" width="60" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="profileName" show-overflow-tooltip align="center" label="文件名称">
                        </el-table-column>
                        <el-table-column show-overflow-tooltip prop="profileType" align="center" label="文件类型">
                            <template v-slot="{ row }">
                                {{ getDictName('sjk_wjlx', row.profileType) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="createTime" width="130" align="center" label="上传时间">
                        </el-table-column>
                        <el-table-column align="center" width="100" label="当前状态">
                            <template v-slot="{ row }">
                                <el-tag v-if="row.status == '1'" type="success">已发布</el-tag>
                                <el-tag v-else type="info">草稿</el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip width="180" align="center" fixed="right" label="操作">
                            <template v-slot="{ row }">
                                <el-link icon="el-icon-edit" type="primary" :underline="false" class="cloumn-btn"
                                    @click="openEdit(row)">
                                    编辑
                                </el-link>
                                <el-link v-if="row.status != '1'" icon="el-icon-finished" type="primary"
                                    :underline="false" class="cloumn-btn" @click="publishOrUnpublish(row, 1)">
                                    发布
                                </el-link>
                                <el-link v-if="row.status == '1'" icon="el-icon-refresh-left" type="danger"
                                    :underline="false" class="cloumn-btn withdraw" @click="publishOrUnpublish(row, 0)">
                                    撤回
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <fileLibraryDialog @refreshData="refreshData" ref="fileLibraryDialog"></fileLibraryDialog>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="params.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import apiList from '@/api/WorkItems/fileLibrary.js'
import fileLibraryDialog from './components/fileLibraryDialog.vue'
import utils from '@/utils.js'
export default {
    name: 'reformDatabase',
    components: {
        pagination,
        fileLibraryDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            reqLoading: false,
            loading: false,
            markLoading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'NOT_EQUAL',
                        parentGroup: '',
                        property: 'profile_Type_',
                        relation: 'AND',
                        value: '7'
                    }
                ]
            },
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            searchForm: {}, // 顶部搜索对象
            deleteIds: '',
            tableData: [],

        }
    },
    created() {
        let data = utils.getDictItemsFromCache('sjk_wjlx')
        this.fileTypeOptions = data.slice(0, -1)
        this.getTableData(this.params)
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        refreshData() {
            this.getTableData(this.params)
        },
        getTableData(data) {
            this.loading = true
            apiList.pagingList(data, (res) => {
                this.tableData = res.rows
                this.params.pageBean.total = res.total
                this.loading = false
            })
        },
        publishOrUnpublish(row, status) {
            let msg = status ? '发布' : '取消发布'
            let type = status ? 'success' : 'error'
            this.$confirm(`确认${msg}吗？`, this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type,
            }).then(() => {
                this.markLoading = true
                let data = {
                    id: row.id,
                    status
                }
                apiList.publishById(data, res => {
                    if (res.state) {
                        this.$message.success(`${msg}成功`)
                        row.status = status
                    }
                    this.markLoading = false
                })
            })

        },
        //添加
        handleAdd() {
            this.$refs.fileLibraryDialog.open('other')
        },
        openEdit(row) {
            this.$refs.fileLibraryDialog.open('other', row)
        },
        // 删除
        handleDelete() {
            this.$confirm('确认删除？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'warning',
            }).then(() => {
                apiList.deleteById(this.deleteIds, (res) => {
                    if (res.state) {
                        this.$message.success('删除成功')
                        this.getTableData(this.params)
                    } else {
                        this.$message.error('删除失败')
                    }
                })
            })
        },
        // 顶部搜索
        handleSearch() {
            this.tableLoading = true
            let data = JSON.parse(JSON.stringify(this.params))
            let obj = JSON.parse(JSON.stringify(this.searchForm))
            let querys = [
                {
                    group: 'main',
                    operation: 'NOT_EQUAL',
                    parentGroup: '',
                    property: 'profile_Type_',
                    relation: 'AND',
                    value: '7'
                }
            ]
            for (let i in obj) {
                if (obj[i]) {
                    querys.push({
                        group: 'main',
                        operation:
                            i == 'profileName'
                                ? 'LIKE'
                                : 'EQUAL',
                        parentGroup: '',
                        property: i,
                        relation: 'AND',
                        value: obj[i],
                    })
                }
            }
            data.querys = querys
            data.pageBean.page = 1
            // this.pageResult.page = page
            this.getTableData(data)
        },

        handleSelectionChange(currentData) {
            if (currentData.length === 0) return (this.deleteIds = '')
            let ids = []
            currentData.forEach((item) => {
                ids.push(item.id)
            })
            this.deleteIds = ids.join(',')
            console.log(this.deleteIds)
        },
        handleCurrentChange(page) {
            this.params.pageBean = { ...this.params.pageBean, page }
            this.getTableData(this.params)
        },
        handleSizeChange(pageSize) {
            this.params.pageBean = { ...this.params.pageBean, pageSize }
            this.getTableData(this.params)
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //     background-color: #f56c6c;
    //     color: #fff;
    //     border-color: #f56c6c;
    // }

    /deep/ i,
    span {
        font-size: 16px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/ .el-collapse-item__content {
    padding-bottom: 5px;
}

.fs-input {
    /deep/ .el-input__inner {
        height: 29px;
        line-height: 18px;
        text-align: center;
    }
}

.upload_file {
    opacity: 1;
    height: 100%;
    pointer-events: auto;
    // transition: all 0.3s;
}

.upload_file_none {
    opacity: 0;
    height: 0;
    pointer-events: none;
    // transition: all 0.3s;
}

/deep/ .el-upload--picture-card {
    display: block;
    border: none;
    width: 100%;
    height: 70px;
    line-height: 70px;
    text-align: left;
}

/deep/.el-upload-list--picture-card .el-upload-list__item {
    width: 100px;
    height: 70px;
}

/deep/ .upload-demo {
    display: flex;
    flex-direction: column-reverse;

    > {
        flex: 1;
    }
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/.el-dialog__body {
        overflow: hidden;
    }
}
</style>
